@@ -112,27 +112,24 @@ def status_report(jobs, width, height=None, tmp_prefix='', dst_prefix=''):
         elif abbreviate_jobs_list and i > n_begin_rows and i < (len(jobs) - n_end_rows):
             continue
 
-        # Regular row
+            # Regular row
         else:
             try:
-                with j.proc.oneshot():
-                    row = [j.plot_id[:8],
-                           j.k,
-                           abbr_path(j.tmpdir, tmp_prefix),
-                           abbr_path(j.dstdir, dst_prefix),
-                           plot_util.time_format(j.get_time_wall()),
-                           phase_str(j.progress()),
-                           plot_util.human_format(j.get_tmp_usage(), 0),
-                           j.proc.pid,
-                           j.get_run_status(),
-                           plot_util.human_format(j.get_mem_usage(), 1),
-                           plot_util.time_format(j.get_time_user()),
-                           plot_util.time_format(j.get_time_sys()),
-                           plot_util.time_format(j.get_time_iowait()),
-                           plot_util.is_freezed(j),
-                           os.path.basename(j.logfile)
-                           ]
-            except (psutil.NoSuchProcess, psutil.AccessDenied):
+                row = [j.plot_id[:8],
+                       j.k,
+                       abbr_path(j.tmpdir, tmp_prefix),
+                       abbr_path(j.dstdir, dst_prefix),
+                       plot_util.time_format(j.get_time_wall()),
+                       phase_str(j.progress()),
+                       plot_util.human_format(j.get_tmp_usage(), 0),
+                       j.proc.pid,
+                       j.get_run_status(),
+                       plot_util.human_format(j.get_mem_usage(), 1),
+                       plot_util.time_format(j.get_time_user()),
+                       plot_util.time_format(j.get_time_sys()),
+                       plot_util.time_format(j.get_time_iowait())
+                       ]
+            except psutil.NoSuchProcess:
                 # In case the job has disappeared
                 row = [j.plot_id[:8]] + (['--'] * 12)
 
